searchData={"items":[{"type":"module","title":"MetaLogger","doc":"A logger wrapper to keep logger metadata of caller processes.","ref":"MetaLogger.html"},{"type":"function","title":"MetaLogger.debug/2","doc":"Logs a debug message keeping logger metadata from caller processes.\nReturns `:ok` or an `{:error, reason}` tuple.","ref":"MetaLogger.html#debug/2"},{"type":"function","title":"Examples - MetaLogger.debug/2","doc":"iex> MetaLogger.debug(\"hello?\")\n    :ok\n\n    iex> MetaLogger.debug(fn -> \"dynamically calculated debug\" end)\n    :ok\n\n    iex> MetaLogger.debug(fn ->\n    ...>   {\"dynamically calculated debug\", [additional: :metadata]}\n    ...> end)\n    :ok","ref":"MetaLogger.html#debug/2-examples"},{"type":"function","title":"MetaLogger.error/2","doc":"Logs a error message keeping logger metadata from caller processes.\nReturns `:ok` or an `{:error, reason}` tuple.","ref":"MetaLogger.html#error/2"},{"type":"function","title":"Examples - MetaLogger.error/2","doc":"iex> MetaLogger.error(\"hello?\")\n    :ok\n\n    iex> MetaLogger.error(fn -> \"dynamically calculated debug\" end)\n    :ok\n\n    iex> MetaLogger.error(fn ->\n    ...>   {\"dynamically calculated error\", [additional: :metadata]}\n    ...> end)\n    :ok","ref":"MetaLogger.html#error/2-examples"},{"type":"function","title":"MetaLogger.info/2","doc":"Logs a info message keeping logger metadata from caller processes.\nReturns `:ok` or an `{:error, reason}` tuple.","ref":"MetaLogger.html#info/2"},{"type":"function","title":"Examples - MetaLogger.info/2","doc":"iex> MetaLogger.info(\"hello?\")\n    :ok\n\n    iex> MetaLogger.info(fn -> \"dynamically calculated debug\" end)\n    :ok\n\n    iex> MetaLogger.info(fn ->\n    ...>   {\"dynamically calculated info\", [additional: :metadata]}\n    ...> end)\n    :ok","ref":"MetaLogger.html#info/2-examples"},{"type":"function","title":"MetaLogger.log/3","doc":"Logs a message with given `level` keeping logger metadata from caller processes.\n\nCan accept a custom struct if it implements MetaLogger.Formatter protocol.\n\nReturns `:ok` or an `{:error, reason}` tuple.","ref":"MetaLogger.html#log/3"},{"type":"function","title":"Examples - MetaLogger.log/3","doc":"iex> MetaLogger.log(:info, \"mission accomplished\")\n    :ok\n\n    iex> MetaLogger.log(:error, fn -> \"dynamically calculated info\" end)\n    :ok\n\n    iex> MetaLogger.log(:warning, fn ->\n    ...>   {\"dynamically calculated info\", [additional: :metadata]}\n    ...> end)\n    :ok","ref":"MetaLogger.html#log/3-examples"},{"type":"function","title":"MetaLogger.metadata/0","doc":"Returns the logger metadata from the current process and caller processes.","ref":"MetaLogger.html#metadata/0"},{"type":"function","title":"Examples - MetaLogger.metadata/0","doc":"iex> MetaLogger.metadata()\n    []\n\n    iex> MetaLogger.metadata()\n    [metadata1: \"value2\", metadata2: \"value2\"]","ref":"MetaLogger.html#metadata/0-examples"},{"type":"function","title":"MetaLogger.warn/2","doc":"Logs a warning message keeping logger metadata from caller processes.\nReturns `:ok` or an `{:error, reason}` tuple.","ref":"MetaLogger.html#warn/2"},{"type":"function","title":"Examples - MetaLogger.warn/2","doc":"iex> MetaLogger.warn(\"hello?\")\n    :ok\n\n    iex> MetaLogger.warn(fn -> \"dynamically calculated debug\" end)\n    :ok\n\n    iex> MetaLogger.warn(fn ->\n    ...>   {\"dynamically calculated warning\", [additional: :metadata]}\n    ...> end)\n    :ok","ref":"MetaLogger.html#warn/2-examples"},{"type":"function","title":"MetaLogger.warning/2","doc":"Logs a warning message keeping logger metadata from caller processes.\nReturns `:ok` or an `{:error, reason}` tuple.","ref":"MetaLogger.html#warning/2"},{"type":"function","title":"Examples - MetaLogger.warning/2","doc":"iex> MetaLogger.warning(\"hello?\")\n    :ok\n\n    iex> MetaLogger.warning(fn -> \"dynamically calculated debug\" end)\n    :ok\n\n    iex> MetaLogger.warning(fn ->\n    ...>   {\"dynamically calculated warning\", [additional: :metadata]}\n    ...> end)\n    :ok","ref":"MetaLogger.html#warning/2-examples"},{"type":"type","title":"MetaLogger.chardata_or_fun/0","doc":"","ref":"MetaLogger.html#t:chardata_or_fun/0"},{"type":"type","title":"MetaLogger.metadata/0","doc":"","ref":"MetaLogger.html#t:metadata/0"},{"type":"type","title":"MetaLogger.payload/0","doc":"","ref":"MetaLogger.html#t:payload/0"},{"type":"protocol","title":"MetaLogger.Formatter","doc":"","ref":"MetaLogger.Formatter.html"},{"type":"function","title":"MetaLogger.Formatter.format/1","doc":"MetaLogger formatter protocol.","ref":"MetaLogger.Formatter.html#format/1"},{"type":"type","title":"MetaLogger.Formatter.t/0","doc":"All the types that implement this protocol.","ref":"MetaLogger.Formatter.html#t:t/0"},{"type":"module","title":"MetaLogger.Slicer","doc":"Responsible for slicing log entries according to the given max length option.","ref":"MetaLogger.Slicer.html"},{"type":"function","title":"MetaLogger.Slicer.slice/2","doc":"Returns sliced log entries according to the given max entry length.\n\nIf the entry is smaller than given max length, or if `:infinity ` is given\nas option, a list with one entry is returned. Otherwise a list with multiple\nentries is returned.","ref":"MetaLogger.Slicer.html#slice/2"},{"type":"function","title":"Examples - MetaLogger.Slicer.slice/2","doc":"iex> MetaLogger.Slicer.slice(\"1234567890\", 10)\n    [\"1234567890\"]\n\n    iex> MetaLogger.Slicer.slice(\"1234567890\", :infinity)\n    [\"1234567890\"]\n\n    iex> MetaLogger.Slicer.slice(\"1234567890\", 5)\n    [\"12345\", \"67890\"]","ref":"MetaLogger.Slicer.html#slice/2-examples"},{"type":"type","title":"MetaLogger.Slicer.max_entry_length/0","doc":"Max length in bytes or `:infinity` if the entry should not be sliced.","ref":"MetaLogger.Slicer.html#t:max_entry_length/0"},{"type":"module","title":"Tesla.Middleware.MetaLogger","doc":"Tesla middleware to log requests and responses.\n\nYou can pass the options to the middleware or to the `Tesla.Env` request . The Tesla env\noptions take precedence over the middleware options.","ref":"Tesla.Middleware.MetaLogger.html"},{"type":"module","title":"Usage example - Tesla.Middleware.MetaLogger","doc":"defmodule MyClient do\n      use Tesla\n\n      plug Tesla.Middleware.MetaLogger,\n        filter_body: [{~r/\"email\":\".*?\"/, ~s(\"email\":\"[FILTERED]\")}],\n        filter_headers: [\"authorization\"],\n        filter_query_params: [:api_key],\n        log_level: :debug,\n        log_tag: MyApp,\n        max_entry_length: :infinity\n    end","ref":"Tesla.Middleware.MetaLogger.html#module-usage-example"},{"type":"module","title":"Options - Tesla.Middleware.MetaLogger","doc":"* `:filter_headers` - The headers that should not be logged, the values will be replaced with\n`[FILTERED]`. Defaults to: `[]`.\n* `:filter_query_params` - The query params that should not be logged, the values will be\nreplaced with `[FILTERED]`. Defaults to: `[]`.\n* `:filter_body` - The request and response body patterns that should not be logged, each\nfilter can be just a pattern, wich will be replaced by `\"[FILTERED]\"`, or it can be a tuple\nwith the pattern and the replacement. Because the body filtering is applied to strings it is\nnecessary that this middleware is the last one on the stack, so it receives the request body\nalready encoded and the response body not yet decoded. If the body is not a string, the\nfiltering will be skipped.\n* `:log_level` - The log level to be used, defaults to: `:info`. Responses with HTTP status\ncode 400 and above will be logged with `:error`, and redirect with `:warning`.\n* `:log_tag` - The log tag to be prefixed in the logs. Any non-string value will be inspect as\na string. Defaults to the current module name.\n* `:max_entry_length` - The maximum length of a log entry before it is splitted into new ones.\nDefaults to `:infinity`.","ref":"Tesla.Middleware.MetaLogger.html#module-options"},{"type":"exception","title":"MetaLogger.Formatter.IncorrectOrNotSetFormatterFunction","doc":"","ref":"MetaLogger.Formatter.IncorrectOrNotSetFormatterFunction.html"},{"type":"exception","title":"MetaLogger.Formatter.IncorrectPayload","doc":"","ref":"MetaLogger.Formatter.IncorrectPayload.html"},{"type":"extras","title":"MetaLogger","doc":"# MetaLogger\n\n[![Hex.pm](https://img.shields.io/hexpm/v/meta_logger.svg)](https://hex.pm/packages/meta_logger)\n[![Docs](https://img.shields.io/badge/hex-docs-542581.svg)](https://hexdocs.pm/meta_logger)\n[![Build Status](https://github.com/FindHotel/meta_logger/workflows/build/badge.svg?branch=master)](https://github.com/FindHotel/meta_logger/actions?query=branch%3Amaster)\n[![License](https://img.shields.io/hexpm/l/meta_logger.svg)](https://github.com/FindHotel/meta_logger/blob/master/LICENSE)\n\nMetaLogger is a wrapper for Elixir `Logger` that keeps and returns the logger metadata from the\ncaller processes.","ref":"readme.html"},{"type":"extras","title":"Installation - MetaLogger","doc":"The package can be installed by adding `meta_logger` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:meta_logger, \"~> 1.7.0\"}\n  ]\nend\n```\n\nMetaLogger requires Elixir 1.10 or greater. For previous Elixir versions use MetaLogger `0.1.0`.","ref":"readme.html#installation"},{"type":"extras","title":"Usage - MetaLogger","doc":"Just replace `Logger` with `MetaLogger`, there is no need to require it before using:\n\n```elixir\nMetaLogger.[debug|error|info|log|warning](...)\n```\n\nFor processes that can continue running after the parent process ends, the `MetaLogger` will not\nbe able to get the caller processes metadata if the parent process is finished. In this case, the\n`MetaLogger.metadata/0` function can be used to store the metadata before the process starts:\n\n```elixir\nmetadata = MetaLogger.metadata()\n\nTask.async(fn ->\n  Logger.metadata(metadata)\nend)\n```","ref":"readme.html#usage"},{"type":"extras","title":"Tesla Middleware - MetaLogger","doc":"A middleware to log requests and responses using [Tesla](https://hexdocs.pm/tesla).","ref":"readme.html#tesla-middleware"},{"type":"extras","title":"Installation - MetaLogger","doc":"If you want to use the MetaLogger Tesla middleware, optional dependencies are required. Add the\nfollowing to your `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:tesla, \"~> 1.4\"},\n    {:miss, \"~> 0.1\"}\n  ]\nend\n```\n\n#","ref":"readme.html#installation"},{"type":"extras","title":"Usage example - MetaLogger","doc":"```elixir\ndefmodule MyClient do\n  use Tesla\n\n  plug Tesla.Middleware.MetaLogger,\n    filter_body: {~r/email=.*&/, \"email=[FILTERED]&\"}\n    filter_headers: [\"authorization\"],\n    filter_query_params: [:api_key],\n    log_level: :debug,\n    log_tag: MyApp,\n    max_entry_length: 22_000\nend\n```\n\n#","ref":"readme.html#usage-example"},{"type":"extras","title":"Options - MetaLogger","doc":"See the [`Tesla.Middleware.MetaLogger`](https://hexdocs.pm/meta_logger/Tesla.Middleware.MetaLogger.html)\ndocumentation for the options definition.","ref":"readme.html#options"},{"type":"extras","title":"MetaLogger.Formatter protocol - MetaLogger","doc":"It is possible to define an implementation for a custom struct, so MetaLogger will know how to\nformat log messages. It also includes the possibility to filter some data using regexp patterns.\n\nIt could be useful, when there is a defined struct with sensitive information, for example after\nan HTTP request. If you own the struct, you can derive the implementation specifying a formatter\nfunction and patterns which will be filtered.\n\nThe struct for which implementation will be used must have the `payload` field, which is used as\ninput for the defined format function.\n\n`MetaLogger.log/3` accepts the structs which derives `MetaLogger.Formatter` implementation.\n\n#","ref":"readme.html#metalogger-formatter-protocol"},{"type":"extras","title":"Usage - MetaLogger","doc":"```elixir\ndefmodule ClientFormatterImpl do\n  @derive {\n    MetaLogger.Formatter,\n    formatter_fn: &__MODULE__.format/1,\n    filter_patterns: [\n      {~s/\"name\":\".*\"/, ~s/\"name\":\"[FILTERED]\"/},\n      \"very_secret_word\"\n    ]\n  }\n\n  def build(payload) do\n    struct!(__MODULE__, payload: payload)\n  end\n\n  def format(%{foo: foo}) do\n    \"Very useful but filtered information: #{inspect(foo)}\"\n  end\nend\n\n# Inside the build function a logic can be defined to extract an useful payload\n# which needs to belogged, e.g. a request and response information.\nhttp_request\n|> ClientFormatterImpl.build()\n|> then(fn log_struct -> MetaLogger.log(:debug, log_struct) end)\n```\n\n#","ref":"readme.html#usage"},{"type":"extras","title":"Options - MetaLogger","doc":"- `:formatter_fn` (required) - The function which is used to format a given payload. The function\n  must return a string or a list of strings.\n- `:filter_patterns` (optional) - Regex patterns which will be used to replace sensitive\n  information in a payload. It is a list of strings or tuples (can be mixed). If tuples are given,\n  the first element is used as a regex pattern to match, and the second is as a replacement which\n  will be used to replace it. E.g. `{~s/\"name\": \".+\"/, ~s/\"name\": \"[FILTERED]\"/}`.","ref":"readme.html#options"},{"type":"extras","title":"Full documentation - MetaLogger","doc":"The full documentation is available at [https://hexdocs.pm/meta_logger](https://hexdocs.pm/meta_logger).","ref":"readme.html#full-documentation"},{"type":"extras","title":"Contributing - MetaLogger","doc":"See the [contributing guide](https://github.com/FindHotel/meta_logger/blob/master/CONTRIBUTING.md).","ref":"readme.html#contributing"},{"type":"extras","title":"License - MetaLogger","doc":"MetaLogger is released under the Apache 2.0 License. See the\n[LICENSE](https://github.com/FindHotel/meta_logger/blob/master/LICENSE) file.\n\nCopyright © 2019-2021 FindHotel","ref":"readme.html#license"},{"type":"extras","title":"Author - MetaLogger","doc":"[FindHotel](https://github.com/FindHotel)","ref":"readme.html#author"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/), and this project\nadheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).\n\n## [Unreleased]\n\n## [1.7.0] - 2024-02-05\n\n#","ref":"changelog.html"},{"type":"extras","title":"Added - Changelog","doc":"- New `MetaLogger.warning/2` function.\n- New `@specs` for:\n  - `MetaLogger.debug/2`\n  - `MetaLogger.info/2`\n  - `MetaLogger.warn/2`\n  - `MetaLogger.warning/2`\n  - `MetaLogger.error/2`\n  - `MetaLogger.log/1`\n\n#","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Changelog","doc":"- `MetaLogger.warn/2` is now deprecated.\n\n## [1.6.1] - 2021-11-05\n\n#","ref":"changelog.html#changed"},{"type":"extras","title":"Changed - Changelog","doc":"- Update documentation.\n\n## [1.6.0] - 2021-11-05\n\n#","ref":"changelog.html#changed"},{"type":"extras","title":"Added - Changelog","doc":"- Add the contributing guide.\n\n#","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Changelog","doc":"- Update dependencies.\n- Update documentation.\n- Rename GitHub Action workflow.\n\n#","ref":"changelog.html#changed"},{"type":"extras","title":"Fixed - Changelog","doc":"- Format query string in Tesla Middleware logs.\n  [Issue #13](https://github.com/FindHotel/meta_logger/issues/13)\n\n## [1.5.0] - 2021-08-26\n\n#","ref":"changelog.html#fixed"},{"type":"extras","title":"Added - Changelog","doc":"- Add `MetaLogger.metadata/0` function to return the logger metadata from the current process and\n  caller processes.\n\n## [1.4.1] - 2021-06-21\n\n#","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Changelog","doc":"- Update `ex_doc`.\n\n## [1.4.0] - 2021-06-21\n\n#","ref":"changelog.html#changed"},{"type":"extras","title":"Added - Changelog","doc":"- Add MetaLogger.Slicer to slice log entries.\n- Add body filtering to Tesla Middleware.\n- Slice log entries on Tesla Middleware.\n\n## [1.3.1] - 2021-06-03\n\n#","ref":"changelog.html#added"},{"type":"extras","title":"Added - Changelog","doc":"- Custom replacements for filter patterns.\n\n## [1.3.0] - 2021-06-02\n\n#","ref":"changelog.html#added"},{"type":"extras","title":"Added - Changelog","doc":"- Add MetaLogger.Formatter protocol.\n- `log\\3` accepts a list as the payload. Each element of the list will be logged separately.\n\n## [1.2.0] - 2021-04-23\n\n#","ref":"changelog.html#added"},{"type":"extras","title":"Added - Changelog","doc":"- Add query params filtering to Tesla Middleware.\n\n#","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Changelog","doc":"- Ensure Tesla is loaded before defining MetaLogger middleware to avoid compilation errors on\n  projects without Tesla.\n\n## [1.1.0] - 2020-12-16\n\n#","ref":"changelog.html#changed"},{"type":"extras","title":"Added - Changelog","doc":"- Add Tesla middleware to log requests and responses.\n\n#","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Changelog","doc":"- Moved from Travis CI to GitHub Actions.\n\n## [1.0.0] - 2020-07-14\n\n#","ref":"changelog.html#changed"},{"type":"extras","title":"Changed - Changelog","doc":"- Changes the required version of Elixir from 1.9 to 1.10.\n\n#","ref":"changelog.html#changed"},{"type":"extras","title":"Fixed - Changelog","doc":"- Gets logger metadata from the correct process dictionary key. Elixir 1.10 uses Erlang logger\n  metadata.\n\n## [0.1.0] - 2019-09-13\n\n#","ref":"changelog.html#fixed"},{"type":"extras","title":"Added - Changelog","doc":"- Keep logger metadata from caller processes.\n\n[Unreleased]: https://github.com/FindHotel/meta_logger/compare/1.7.0...HEAD\n[1.7.0]: https://github.com/FindHotel/meta_logger/compare/1.6.1...1.7.0\n[1.6.1]: https://github.com/FindHotel/meta_logger/compare/1.6.0...1.6.1\n[1.6.0]: https://github.com/FindHotel/meta_logger/compare/1.5.0...1.6.0\n[1.5.0]: https://github.com/FindHotel/meta_logger/compare/1.4.1...1.5.0\n[1.4.1]: https://github.com/FindHotel/meta_logger/compare/1.4.0...1.4.1\n[1.4.0]: https://github.com/FindHotel/meta_logger/compare/1.3.1...1.4.0\n[1.3.1]: https://github.com/FindHotel/meta_logger/compare/1.3.0...1.3.1\n[1.3.0]: https://github.com/FindHotel/meta_logger/compare/1.2.0...1.3.0\n[1.2.0]: https://github.com/FindHotel/meta_logger/compare/1.1.0...1.2.0\n[1.1.0]: https://github.com/FindHotel/meta_logger/compare/1.0.0...1.1.0\n[1.0.0]: https://github.com/FindHotel/meta_logger/compare/0.1.0...1.0.0\n[0.1.0]: https://github.com/FindHotel/meta_logger/releases/tag/0.1.0","ref":"changelog.html#added"}],"content_type":"text/markdown"}